@@ -90,7 +90,7 @@
 #' A set of trophic discrimination factors for brent geese feeding on their
 #' sources.
 #'
-#' A dataset of estimated trophic discriminaton factors for brent geese. The
+#' A dataset of estimated trophic discrimination factors for brent geese. The
 #' data assume the same TDF for each food source. Intended for use in a Stable
 #' Isotope Mixing Model.
 #'
@@ -157,3 +157,26 @@
 #' @keywords datasets
 #' @author Rich Inger
 "sourcesdemo"
+
+
+#' A set of isotope observations for mongooses nested within packs
+#'
+#' A dataset of multiple isotopes per individual mongooses nested within packs 
+#' where the goal is to understand isotopic niche occupancy of individuals 
+#' with respect to their own pack.
+#'
+#' @docType data
+#'
+#' @usage data(mongoose)
+#'
+#' @format A 4 column, 783 row data.frame object containing unique individual 
+#' mongoose identifiers in the first column "indiv.id"; an integer identifier for 
+#' the pack to which each individual belongs in "pack"; Delta 13 Carbon values 
+#' "c13; and Delta 15 Nitrogen values in "n15". See the paper Sheppard et al 
+#' 2018 https://doi.org/10.1111/ele.12933 for more details, although N.B. 
+#' the data here are provided as an example, not as a reproducible analysis of 
+#' that paper. 
+#'
+#' @keywords datasets
+#' @author Harry Marshall
+"mongoose"
